RedisConnKey

Struct RedisConnKey 

pub struct RedisConnKey {
    pub node: NodeSpec,
    pub read_from_replicas: bool,
    pub username: Option<String>,
    pub password: Option<String>,
    pub cluster: Option<bool>,
    pub pool_size: Option<usize>,
    pub connect_timeout: Option<Duration>,
    pub recycle_timeout: Option<Duration>,
    pub wait_timeout: Option<Duration>,
    pub response_timeout: Option<Duration>,
}

Fields

node: NodeSpecread_from_replicas: bool

Enables reading from replicas for all new connections

username: Option<String>password: Option<String>cluster: Option<bool>pool_size: Option<usize>

Maximum number of connections managed by the pool. Default is 10

connect_timeout: Option<Duration>recycle_timeout: Option<Duration>wait_timeout: Option<Duration>response_timeout: Option<Duration>

Implementations

Source

impl RedisConnKey

pub fn build_client(&self) -> Result<ClientWrapper>

pub fn get_pool(&self) -> Result<Pool<ClientManager>>

pub fn open(&self) -> Result<RedisConnection>

pub fn hash_label(&self) -> String

Produces a human readable label string that is representitive of this RedisConnKey. We pull out the node and username to include in the label. Now, since the entire RedisConnKey is the actual key, that readable subset is not sufficient to uniquely identify the entry in the pool, although in reality it is probably OK, there exists the possibility that eg: on a config update, multiple entries have the same list of nodes but different auth or other parameters. To smooth over such a transition, we’ll include a basic crc32 of the entire RedisConnKey in the label that is returned. This will probably be sufficient to avoid an obvious collision between such names, but it will not guarantee it. This is a best effort really; I doubt that this will cause any meaningful issues in practice, as the intended use case for this label string is to sample metrics rather than to guarantee isolation.